Customer Results
================

.. automodule:: icometrix_sdk.resources.customer_results


.. autoclass:: icometrix_sdk.resources.customer_results.CustomerResults
    :members:
    :show-inheritance:
